==> ckeditor_4.4.4+dfsg1.orig.tar.xz: ckeditor-dev-4.4.4/plugins/forms/lang/hu.js <==
﻿/*
Copyright (c) 2003-2014, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang( 'forms', 'hu', {
	button: {
		title: 'Gomb tulajdonságai',
		text: 'Szöveg (Érték)',
		type: 'Típus',
		typeBtn: 'Gomb',
		typeSbm: 'Küldés',
		typeRst: 'Alaphelyzet'
	},
	checkboxAndRadio: {
		checkboxTitle: 'Jelölőnégyzet tulajdonságai',
		radioTitle: 'Választógomb tulajdonságai',
		value: 'Érték',
		selected: 'Kiválasztott'
	},
	form: {
		title: 'Űrlap tulajdonságai',
		menu: 'Űrlap tulajdonságai',
		action: 'Adatfeldolgozást végző hivatkozás',
		method: 'Adatküldés módja',
		encoding: 'Kódolás'
	},
	hidden: {
		title: 'Rejtett mező tulajdonságai',
		name: 'Név',
		value: 'Érték'
	},
	select: {
		title: 'Legördülő lista tulajdonságai',
		selectInfo: 'Alaptulajdonságok',
		opAvail: 'Elérhető opciók',
		value: 'Érték',
		size: 'Méret',
		lines: 'sor',
		chkMulti: 'több sor is kiválasztható',
		opText: 'Szöveg',
		opValue: 'Érték',
		btnAdd: 'Hozzáad',
		btnModify: 'Módosít',
		btnUp: 'Fel',
		btnDown: 'Le',
		btnSetValue: 'Legyen az alapértelmezett érték',
		btnDelete: 'Töröl'
	},
	textarea: {
		title: 'Szövegterület tulajdonságai',
		cols: 'Karakterek száma egy sorban',
		rows: 'Sorok száma'
	},
	textfield: {
		title: 'Szövegmező tulajdonságai',
		name: 'Név',
		value: 'Érték',
		charWidth: 'Megjelenített karakterek száma',
		maxChars: 'Maximális karakterszám',
		type: 'Típus',
		typeText: 'Szöveg',
		typePass: 'Jelszó',
		typeEmail: 'Ímél',
		typeSearch: 'Keresés',
		typeTel: 'Telefonszám',
		typeUrl: 'URL'
	}
} );

==> ckeditor_4.5.7+dfsg.orig.tar.xz: ckeditor-dev-4.5.7/plugins/forms/lang/hu.js <==
/*
Copyright (c) 2003-2016, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang( 'forms', 'hu', {
	button: {
		title: 'Gomb tulajdonságai',
		text: 'Szöveg (Érték)',
		type: 'Típus',
		typeBtn: 'Gomb',
		typeSbm: 'Küldés',
		typeRst: 'Alaphelyzet'
	},
	checkboxAndRadio: {
		checkboxTitle: 'Jelölőnégyzet tulajdonságai',
		radioTitle: 'Választógomb tulajdonságai',
		value: 'Érték',
		selected: 'Kiválasztott',
		required: 'Required' // MISSING
	},
	form: {
		title: 'Űrlap tulajdonságai',
		menu: 'Űrlap tulajdonságai',
		action: 'Adatfeldolgozást végző hivatkozás',
		method: 'Adatküldés módja',
		encoding: 'Kódolás'
	},
	hidden: {
		title: 'Rejtett mező tulajdonságai',
		name: 'Név',
		value: 'Érték'
	},
	select: {
		title: 'Legördülő lista tulajdonságai',
		selectInfo: 'Alaptulajdonságok',
		opAvail: 'Elérhető opciók',
		value: 'Érték',
		size: 'Méret',
		lines: 'sor',
		chkMulti: 'több sor is kiválasztható',
		required: 'Required', // MISSING
		opText: 'Szöveg',
		opValue: 'Érték',
		btnAdd: 'Hozzáad',
		btnModify: 'Módosít',
		btnUp: 'Fel',
		btnDown: 'Le',
		btnSetValue: 'Legyen az alapértelmezett érték',
		btnDelete: 'Töröl'
	},
	textarea: {
		title: 'Szövegterület tulajdonságai',
		cols: 'Karakterek száma egy sorban',
		rows: 'Sorok száma'
	},
	textfield: {
		title: 'Szövegmező tulajdonságai',
		name: 'Név',
		value: 'Érték',
		charWidth: 'Megjelenített karakterek száma',
		maxChars: 'Maximális karakterszám',
		required: 'Required', // MISSING
		type: 'Típus',
		typeText: 'Szöveg',
		typePass: 'Jelszó',
		typeEmail: 'Ímél',
		typeSearch: 'Keresés',
		typeTel: 'Telefonszám',
		typeUrl: 'URL'
	}
} );
